%this is the masterfile to do all our empirical applications
clear;
rng(1)
%create a folder "FiguresandTables" under this path to save figures and tables

%picking which application to run
% 1: econ experiments
% 2: econ experiments, p(z,theta) specification test. No corrections for
% this application
% 3: psychology experiments
% 4: psychology experiments, approved replications
% 5: psychology experiments, denominator dof>=30
% 6: psychology experiments, p(z,theta) specification test.  No corrections for
% this application
% 7: minimum wage effect
% 8: minimum wage effect, published
% 9: minimum wage, no selection
% 10: deworming
% 11: deworming, asymmetric
% 12: deworming, asymmetric, single discontinuity
% 13: deworming, no selection

application=1;

% whether we want to produce figures, and/or estimates, and/or bias corrections
dofigures=1;
doestimates=1;
docorrections=1;

%simulations draws for p(z,theta) specifications
zdrawcount=5*10^3;
thetadrawcount=5*10^3;
zdrawsd=5;
thetadrawsd=4;
vcutoff=1.96;

%variable identificationapproach will be set later
% 1: replications
% 2: variation in variance

%%
%loading the data
if application == 1
    
    Studynames = textscan(fopen('../Applications/EconExperiments/sorted_names.csv','r'), '%s%[^\n\r]', 'Delimiter', ';');
    Studynames=Studynames{1}
    
    data=csvread('../Applications/EconExperiments/cleaned_econ_data.csv');
    Z=[data(:,1)./data(:,2) data(:,3)./data(:,2)];
    sigmaZ2=data(:,4)./data(:,2);
    
    n=size(Z,1);
    cluster_ID=(1:n)';
    
    X=data(:,1);
    sigma=data(:,2);
    
    identificationapproach=1;
    name='ReplicationEcon';
    
    %Estimate baseline model, rather than running spec test
    spec_test=0;   
    %Set number of normal draws for monte-carlo integration
    ndraws=10^4;
    %Set cutoffs to use in step function: should be given in increasing order;
    cutoffs=1.96;
    %Use a step function symmetric around zero
    symmetric=1;
    %starting values for optimization
    Psihat0=[2,1];    %[tau, betap(1)]
    
elseif application == 2
    Studynames = textscan(fopen('../Applications/EconExperiments/sorted_names.csv','r'), '%s%[^\n\r]', 'Delimiter', ';');
    Studynames=Studynames{1}
    
    data=csvread('../Applications/EconExperiments/cleaned_econ_data.csv');
    Z=[data(:,1)./data(:,2) data(:,3)./data(:,2)];
    sigmaZ2=data(:,4)./data(:,2);
    
    Zdraws=randn(zdrawcount,1)*zdrawsd;
    Thetadraws=randn(thetadrawcount,1)*thetadrawsd;
    
    n=size(Z,1);
    cluster_ID=(1:n)';
    X=data(:,1);
    sigma=data(:,2);
    %normalize mean standard deviation to one
    X=X/mean(sigma);
    sigma=sigma/mean(sigma);
    
    
    identificationapproach=1;
    name='ReplicationEconSpecTest';
    
    %Run spec test of baseline model which assumes selection p(z)
    spec_test=1;
    %Set cutoffs to use in step function: should be given in increasing order;
    cutoffs=1.96;
    %Use a step function symmetric around zero
    symmetric=1;
    %starting values for optimization
    Psihat0=[1,1];
    
elseif application == 3
    %Studynames = textscan(fopen('../Applications/PsychExperiments/sorted_1stAuthor.csv','r'), '%s%[^\n\r]', 'Delimiter', ';');
    %Studynames=Studynames{1}
    
    data=csvread('../Applications/PsychExperiments/cleaned_psych_data.csv');
    dofis1=data(:,7)==1;
    use=dofis1;
    data=data(use,:);
    
    Z=[data(:,1)./data(:,2) data(:,3)./data(:,2)];  
    sigmaZ2=data(:,4)./data(:,2);
    n=size(Z,1);
    cluster_ID=(1:n)';
    Studynames=char.empty(0,n);
    
    X=data(:,1);
    sigma=data(:,2);
    
    identificationapproach=1;
    name='ReplicationPsych';
    
    %Estimate baseline model, rather than running spec test
    spec_test=0;
    %Set cutoffs to use in step function: should be given in increasing order;
    cutoffs=[1.64 1.96]';
    %Use a step function symmetric around zero
    symmetric=1;
    %starting values for optimization
    Psihat0=[1,1,1];    %[tau, betap(1), betap(2)]
    
elseif application == 4
    %Studynames = textscan(fopen('../Applications/PsychExperiments/sorted_1stAuthor.csv','r'), '%s%[^\n\r]', 'Delimiter', ';');
    %Studynames=Studynames{1}   
    
    data=csvread('../Applications/PsychExperiments/cleaned_psych_data.csv');
    approved=logical(data(:,5));
    dofis1=data(:,7)==1;
    use=dofis1&approved;
    data=data(use,:);
    
    Z=[data(:,1)./data(:,2) data(:,3)./data(:,2)];
    sigmaZ2=data(:,4)./data(:,2);
    
    n=size(Z,1);
    Studynames=char.empty(0,n)
    cluster_ID=(1:n)';
    
    X=data(:,1);
    sigma=data(:,2);
    
    identificationapproach=1;
    name='ReplicationPsychApproved';
    
    %Estimate baseline model, rather than running spec test
    spec_test=0;
    %Set cutoffs to use in step function: should be given in increasing order;
    cutoffs=[1.64 1.96]';
    %Use a step function symmetric around zero
    symmetric=1;
    %starting values for optimization
    Psihat0=[1,1,1];    %[tau, betap(1), betap(2)]
 
    elseif application == 5
    %Studynames = textscan(fopen('../Applications/PsychExperiments/sorted_1stAuthor.csv','r'), '%s%[^\n\r]', 'Delimiter', ';');
    %Studynames=Studynames{1}
    
    data=csvread('../Applications/PsychExperiments/cleaned_psych_data.csv');
    dofis1=data(:,7)==1;
    denominatordof30=data(:,8)==0|data(:,8)>=30;
    use=dofis1&denominatordof30;
    data=data(use,:);
    
    Z=[data(:,1)./data(:,2) data(:,3)./data(:,2)];  
    sigmaZ2=data(:,4)./data(:,2);
    n=size(Z,1);
    cluster_ID=(1:n)';
    Studynames=char.empty(0,n);
    
    X=data(:,1);
    sigma=data(:,2);
    
    identificationapproach=1;
    name='ReplicationPsychLargedof';
    
    %Estimate baseline model, rather than running spec test
    spec_test=0;  
    %Set cutoffs to use in step function: should be given in increasing order;
    cutoffs=[1.64 1.96]';
    %Use a step function symmetric around zero
    symmetric=1;
    %starting values for optimization
    Psihat0=[2,1,1];    %[tau, betap(1), betap(2)]
    
elseif application == 6
    Studynames = textscan(fopen('../Applications/PsychExperiments/sorted_1stAuthor.csv','r'), '%s%[^\n\r]', 'Delimiter', ';');
    Studynames=Studynames{1}
    data=csvread('../Applications/PsychExperiments/cleaned_psych_data.csv');
    Z=[data(:,1)./data(:,2) data(:,3)./data(:,2)];
    sigmaZ2=data(:,4)./data(:,2);
    
    Zdraws=randn(zdrawcount,1)*zdrawsd;
    Thetadraws=randn(thetadrawcount,1)*thetadrawsd;
    
    n=size(Z,1);
    cluster_ID=(1:n)';
    X=data(:,1);
    sigma=data(:,2);
    %normalize mean standard deviation to one
    X=X/mean(sigma);
    sigma=sigma/mean(sigma);
    
    identificationapproach=1;
    name='ReplicationPsychSpecTest';
    
    %Run spec test of baseline model which assumes selection p(z)
    spec_test=1;
    %Set number of normal draws for monte-carlo integration
    ndraws=10^4;
    %Set cutoffs to use in step function: should be given in increasing order;
    cutoffs=[1.64 1.96]';
    %Use a step function symmetric around zero
    symmetric=1;
    %starting values for optimization
    Psihat0=[1,1,1];    %[tau, betap(1), betap(2)]
    
elseif application == 7
    data=csvread('../Applications/MinimumWagev2/cleaned_minwage_data.csv');
    X=data(:,1);
    X=-X; %flipping sign so that negative employment effects mean X>0
    sigma=data(:,2);
    n=length(X);
    Studynames=char.empty(0,n)
    cluster_ID=data(:,3); 
    
    includeinfigure=logical(ones(n,1));
    includeinestimation=logical(ones(n,1));
    
    identificationapproach=2;
    name='MinimumWage';
    spec_test=0;
    
    %Set cutoffs to use in step function: should be given in increasing order;
    cutoffs=[-1.96 0 1.96]';
    %Use a step function which may by asymmetric around zero
    symmetric=0;
    symmetric_p=0;
    %starting values for optimization
    Psihat0=[0,1.1,1,1,1];    %[thetabar, tau, betap(1), betap(2), betap(3)]
    
elseif application == 8
    data=csvread('../Applications/MinimumWagev2/cleaned_minwage_data.csv');
    X=data(:,1);
    X=-X; %flipping sign so that negative employment effects mean X>0
    sigma=data(:,2);
    cluster_ID=data(:,3);
    
    published=data(:,4);
    use=published==1;
    X=X(use,:);
    sigma=sigma(use,:);
    cluster_ID=cluster_ID(use,:);
    
    n=length(X);
    Studynames=char.empty(0,n);
    
    % 	includeinfigure=(abs(X)<3)&(sigma<2);
    %     includeinestimation=(sigma<0.5);
    includeinfigure=logical(ones(n,1));
    includeinestimation=logical(ones(n,1));
    
    identificationapproach=2;
    name='MinimumWagePublished';
    spec_test=0;
    
    %Set cutoffs to use in step function: should be given in increasing order;
    cutoffs=[-1.96 0 1.96]';
    %Use a step function which may be asymmetric around zero
    symmetric=0;
    symmetric_p=0;
    %starting values for optimization
    Psihat0=[0,1,1,1,1];    %[thetabar, tau, betap(1), betap(2), betap(3)]
    
elseif application == 9
    data=csvread('../Applications/MinimumWagev2/cleaned_minwage_data.csv');
    X=data(:,1);
    X=-X; %flipping sign so that negative employment effects mean X>0
    sigma=data(:,2);
    cluster_ID=data(:,3);
    
    published=data(:,4);
    use=published==1;
    X=X(use,:);
    sigma=sigma(use,:);
    cluster_ID=cluster_ID(use,:);
    
    n=length(X);
    Studynames=char.empty(0,n);
    
    includeinfigure=logical(ones(n,1));
    includeinestimation=logical(ones(n,1));
    
    identificationapproach=2;
    name='MinimumWageNoSelection';
    spec_test=0;
    
    %Set cutoffs to use in step function: should be given in increasing order;
    cutoffs=0;
    %Use a step function which may be asymmetric around zero
    symmetric=0;
    symmetric_p=1;
    %starting values for optimization
    Psihat0=[0,1];    %[thetabar, tau]
    
elseif application == 10
    data=csvread('../Applications/deworming/cleaned_deworming_data.csv');
    Studynames=table2array(readtable('../Applications/deworming/DewormingLabels.csv'))
    X=data(:,1);
    sigma=data(:,2);
    n=length(X);
    cluster_ID=data(:,3);
    
    includeinfigure=logical(ones(n,1));
    includeinestimation=logical(ones(n,1));
    
    identificationapproach=2;
    name='Deworming';
    spec_test=0;
    
    %Set cutoffs to use in step function: should be given in increasing order;
    cutoffs=[-1.96 0 1.96];
    %Use a step function symmetric around zero for p(z), but don't enforce
    %symmetric distribution of true effects
    symmetric=0;
    symmetric_p=1;
    %starting values for optimization
    Psihat0=[0,1,1]; %[thetabar, tau, betap(1)]
    
elseif application == 11
    data=csvread('../Applications/deworming/cleaned_deworming_data.csv');
    Studynames=table2array(readtable('../Applications/deworming/DewormingLabels.csv'))
    X=data(:,1);
    sigma=data(:,2);
    n=length(X);
    cluster_ID=data(:,3);
    
    includeinfigure=logical(ones(n,1));
    includeinestimation=logical(ones(n,1));
    
    identificationapproach=2;
    name='DewormingAsymmetric';
    spec_test=0;
    
    %Set cutoffs to use in step function: should be given in increasing order;
    cutoffs=[-1.96 0 1.96];
    %Allow an asymmetric specification of p(z)
    symmetric=0;
    symmetric_p=0;
    %starting values for optimization
    Psihat0=[0,1,1,1,1]; %[thetabar, tau, betap(1), betap(2), betap(3)]
    
elseif application == 12
    data=csvread('../Applications/deworming/cleaned_deworming_data.csv');
    Studynames=table2array(readtable('../Applications/deworming/DewormingLabels.csv'))
    X=data(:,1);
    sigma=data(:,2);
    n=length(X);
    cluster_ID=data(:,3);
    
    includeinfigure=logical(ones(n,1));
    includeinestimation=logical(ones(n,1));
    
    identificationapproach=2;
    name='DewormingRestrictedAsymmetric';
    spec_test=0;
    
    %Set cutoffs to use in step function: should be given in increasing order;
    cutoffs=0;
    %Allow an asymmetric specification of p(z)
    symmetric=0;
    symmetric_p=0;
    %starting values for optimization
    Psihat0=[0,1,1]; %[thetabar, tau, betap(1)]
    
    elseif application == 13
    data=csvread('../Applications/deworming/cleaned_deworming_data.csv');
    Studynames=table2array(readtable('../Applications/deworming/DewormingLabels.csv'))
    X=data(:,1);
    sigma=data(:,2);
    n=length(X);
    cluster_ID=data(:,3);
    
    includeinfigure=logical(ones(n,1));
    includeinestimation=logical(ones(n,1));
    
    identificationapproach=2;
    name='DewormingNoSelection';
    spec_test=0;
    
    %Set cutoffs to use in step function: should be given in increasing order;
    cutoffs=0;
    %Use a step function symmetric around zero for p(z), but don't enforce
    %symmetric distribution of true effects
    symmetric=0;
    symmetric_p=1;
    %starting values for optimization
    Psihat0=[0,1]; %[thetabar, tau]
end


%%
%producing figures
if dofigures==1
    if identificationapproach==1
        DescriptiveStats(Z,sigmaZ2, 1,name,symmetric,cluster_ID);
        DescriptiveStats(data(:,1),data(:,2), 2,[name 'Sanitycheck'],symmetric,cluster_ID);
        DescriptiveStatsCombined(Z,data(:,1),data(:,2),name,symmetric);
    else
        DescriptiveStats(X,sigma, 2,name,symmetric,cluster_ID);
    end
end

%%
%estimating the model

if doestimates==1
    EstimatingSelection
end


%%
%producing bias-corrected estimates and confidence sets

if docorrections ==1
    HorizontalBars
end