function [LLH, logL] = ...
    ReplicationAnalyticLogLikelihood(nuhat, tauhat, betap, cutoffs, symmetric, Z, sigmaZ2)

%arguments: mean and stdev of distribution pi of mu
%coefficient vector for step function p, in increasing order
%vector of thresholds for step function p, in increasing order
%dummy for symmetric step function: if one, all cutoffs should be positive
%n by 2 matrix of estimates
%vector of stdevs of X2

n=length(Z(:,1));
k=length(betap);
betap=betap';

%%%create step function
Z1_dummies=zeros(n,length(cutoffs)+1);
if symmetric==1
    Z1_dummies(:,1)=abs(Z(:,1))<cutoffs(1);
    if length(cutoffs)>1
        for m=2:length(cutoffs)
            Z1_dummies(:,m)=(abs(Z(:,1))<cutoffs(m)).*(abs(Z(:,1))>=cutoffs(m-1));
        end
    end
    Z1_dummies(:,end)=abs(Z(:,1))>=cutoffs(end);
else
    Z1_dummies(:,1)=Z(:,1)<cutoffs(1);
    if length(cutoffs)>1
        for m=2:length(cutoffs)
            Z1_dummies(:,m)=(Z(:,1)<cutoffs(m)).*(Z(:,1)>=cutoffs(m-1));
        end
    end
    Z1_dummies(:,end)=Z(:,1)>=cutoffs(end);
end

%%%%%%%%%%%%%%%%%%%%%%%%
% Calculate objective function LLH

%calculating components of the likelihood
phat=Z1_dummies*betap; %vector of estimated publication probabilities, step function model

% %likelihoods calculated by numerical integration
% piZ1Z2=zeros(n,1); %vector of un-truncated likelihoods
% for i=1:n
%     piZ1Z2(i)=2*normpdf(Z(i,1)-mudraws)'*1/sigmaZ2(i)*normpdf((Z(i,2)-mudraws)/sigmaZ2(i))/ndraws;
% end

%likelihoods calculated analytically
piZ1Z2=zeros(n,1); %vector of un-truncated likelihoods
for i=1:n
    Omega=[1+tauhat^2,tauhat^2;tauhat^2,sigmaZ2(i)^2+tauhat^2];
     piZ1Z2(i)=0.5*mvnpdf([Z(i,1), Z(i,2)],nuhat,Omega)...
         +0.5*mvnpdf([Z(i,1), Z(i,2)],-nuhat,Omega);
end


%normalizing constant
mu=nuhat;
sigma=sqrt(tauhat.^2+1);
%calculate probability that T statistic based on X_i has absolute value
%less than critval
prob_vec=zeros(length(cutoffs)+1,1);
if symmetric==1
    for m=1:length(cutoffs)
        prob_vec(m+1)=0.5*(normcdf((cutoffs(m)-mu)/sigma)-normcdf((-cutoffs(m)-mu)/sigma)) +...
            0.5*(normcdf((cutoffs(m)+mu)/sigma)-normcdf((-cutoffs(m)+mu)/sigma));
    end
    prob_vec(end+1,1)=1;
    mean_Z1=prob_vec(2:end,1)-prob_vec(1:end-1,1);
else
    for m=1:length(cutoffs)
        prob_vec(m+1)=0.5*normcdf((cutoffs(m)-mu)/sigma)+0.5*normcdf((cutoffs(m)+mu)/sigma);
    end
    prob_vec(end+1,1)=1;
    mean_Z1=prob_vec(2:end,1)-prob_vec(1:end-1,1);
end
normalizingconst=mean_Z1'*betap;

%vector of likelihoods
L=phat.*piZ1Z2/normalizingconst; %cf equation 3 in the note
logL=log(L);

LLH=-sum(log(L)); %objective function; note the sign flip, since we are doing minimization
end